==> pure-www-18.4.32.47.zip: src/www/Dialvox/application/language/spanish/homeagente_lang.php <==
<?php

$lang["desc_campanaSinListaNegra"] = "La campaña no tiene lista negra";
$lang["desc_noSe"] = "No se que hiciste";
$lang["desc_sinSesion"] = "No hay sesion iniciada";
$lang["desc_noSupervisor"] = "No es un supervisor";
$lang["desc_usuarioInexistente"] = "El usuario no existe";
$lang["desc_guardarLog"] = "No se pudo guardar el log";
$lang["desc_callbackRegistrado"] = "Callback registrado correctamente";
$lang["desc_callbackEliminado"] = "Callback eliminado correctamente";
$lang["desc_sinCallbacks"] = "No hay callbacks por asignar";

$lang["men_callbackAsignado"] = "Callback asignado correctamente";
$lang["men_callbacksObtenidos"] = "Callbacks obtenidos exitosamente";


// Textos en la vista de agente =======================================================

$lang["llamadasPendientes"] = "LLAMADAS PENDIENTES";
$lang["solicitaAyuda"] = "Solicitar ayuda a un supervisor";
$lang["salir"] = "Salir";
$lang["controles"] = "Controles";
$lang["historialLlamadas"] = "Historial de llamadas";
$lang["llamadasSesion"] = "Llamadas de la sesión";
$lang["sinGrabacion"] = "Sin grabación";
$lang["sinLlamadas"] = "No hay llamadas en esta sesion";
$lang["canales"] = "Canales";
$lang["enviarReporte"] = "Enviar reporte";
$lang["notasReporte"] = "Ingresa aqui las notas sobre lo que paso";
$lang["llamando"] = "Llamando";
$lang["calificar"] = "Calificar";
$lang["fechaVolverLlamar"] = "Fecha para volver a llamar";
$lang["horaVolverLlamar"] = "Hora para volver a llamar";
$lang["comentariosCallback"] = "Comentarios para callback";
$lang["tipoCallback"] = "Tipo de Callback";
$lang["callbackCualquiera"] = "Cualquiera";
$lang["callbackYo"] = "Solo yo";
$lang["calificacion"] = "Calificación";
$lang["comentarios"] = "Comentarios";
$lang["pausaCalificar"] = "Poner en pausa al calificar";
$lang["codigosPausa"] = "Códigos de pausa";
$lang["codigoPausa"] = "Código de pausa";
$lang["limitePausa"] = "¡Has superado los limites configurados para este tipo de pausa!";
$lang["ingresaSupervisor"] = "Se requiere que un supervisor ingrese su usuario y contraseña.";
$lang["usuario"] = "Usuario";
$lang["password"] = "Contraseña";
$lang["acceder"] = "Acceder";
$lang["agregarLlamada"] = "Agregar a la llamada";
$lang["telefono"] = "Telefono";
$lang["cerrar"] = "Cerrar";
$lang["marcar"] = "Marcar";
$lang["aviso"] = "Aviso";
$lang["espera"] = "Poner en espera";
$lang["colgar"] = "Colgar";
$lang["volverMarcar"] = "Volver a marcar";
$lang["transferir"] = "Transferir llamada";
$lang["multiplesDtmf"] = "Envio de multiples DTMF";
$lang["avisoDtmf"] = "Solo numeros o caracteres especiales como \'*\' o \'#\'";
$lang["confirmar"] = "Confirmar";
$lang["cancelar"] = "Cancelar";


// Textos en la vista de agente =======================================================



?>

==> pure-www-18.5.21.zip: src/www/Dialvox/application/language/spanish/homeagente_lang.php <==
<?php

$lang["desc_campanaSinListaNegra"] = "La campaña no tiene lista negra";
$lang["desc_noSe"] = "No se que hiciste";
$lang["desc_sinSesion"] = "No hay sesion iniciada";
$lang["desc_noSupervisor"] = "No es un supervisor";
$lang["desc_usuarioInexistente"] = "El usuario no existe";
$lang["desc_guardarLog"] = "No se pudo guardar el log";
$lang["desc_callbackRegistrado"] = "Callback registrado correctamente";
$lang["desc_callbackEliminado"] = "Callback eliminado correctamente";
$lang["desc_sinCallbacks"] = "No hay callbacks por asignar";

$lang["men_callbackAsignado"] = "Callback asignado correctamente";
$lang["men_callbacksObtenidos"] = "Callbacks obtenidos exitosamente";


// Textos en la vista de agente =======================================================

$lang["llamadasPendientes"] = "LLAMADAS PENDIENTES";
$lang["solicitaAyuda"] = "Solicitar ayuda a un supervisor";
$lang["salir"] = "Salir";
$lang["controles"] = "Controles";
$lang["historialLlamadas"] = "Historial de llamadas";
$lang["llamadasSesion"] = "LLAMADAS DEL DÍA";
$lan["historialGrabacion"] = "Grabación";
$lang["sinGrabacion"] = "Sin grabación";
$lang["sinLlamadas"] = "No hay llamadas en esta sesion";
$lang["canales"] = "Audios";
$lang["enviarReporte"] = "Enviar reporte";
$lang["notasReporte"] = "Ingresa aqui las notas sobre lo que paso";
$lang["llamando"] = "Llamando";
$lang["calificar"] = "Calificar";
$lang["fechaVolverLlamar"] = "Fecha para volver a llamar";
$lang["horaVolverLlamar"] = "Hora para volver a llamar";
$lang["comentariosCallback"] = "Comentarios para callback";
$lang["tipoCallback"] = "Tipo de Callback";
$lang["callbackCualquiera"] = "Cualquiera";
$lang["callbackYo"] = "Solo yo";
$lang["calificacion"] = "Calificación";
$lang["comentarios"] = "Comentarios";
$lang["pausaCalificar"] = "Poner en pausa al calificar";
$lang["codigosPausa"] = "Códigos de pausa";
$lang["codigoPausa"] = "Código de pausa";
$lang["limitePausa"] = "¡Has superado los limites configurados para este tipo de pausa!";
$lang["ingresaSupervisor"] = "Se requiere que un supervisor ingrese su usuario y contraseña.";
$lang["usuario"] = "Usuario";
$lang["password"] = "Contraseña";
$lang["acceder"] = "Acceder";
$lang["agregarLlamada"] = "Agregar a la llamada";
$lang["telefono"] = "Telefono";
$lang["cerrar"] = "Cerrar";
$lang["marcar"] = "Marcar";
$lang["aviso"] = "Aviso";
$lang["espera"] = "Poner en espera";
$lang["colgar"] = "Colgar";
$lang["volverMarcar"] = "Volver a marcar";
$lang["transferir"] = "Transferir llamada";
$lang["multiplesDtmf"] = "Envio de multiples DTMF";
$lang["avisoDtmf"] = "Solo numeros o caracteres especiales como \'*\' o \'#\'";
$lang["confirmar"] = "Confirmar";
$lang["cancelar"] = "Cancelar";

$lang["transferenciaAgenteTitulo"] = "Transferir al agente";
$lang["gruposAgente"] = "Categorías de agente";

// Textos en la vista de agente =======================================================
